import { resolve } from "path";
import { readFileSync } from "fs";
import { getVersion } from "@jest/core";
import loader from "graphql-tag";
function indexesOf(array, predicate) {
    const indexes = [];
    for (let i = 0; i < array.length; i++) {
        const arrayElement = array[i];
        if (predicate(arrayElement, i, array)) {
            indexes.push(i);
        }
    }
    return indexes;
}
function doImports(sourceLines, sourcePath, loadedFiles = new Set()) {
    if (loadedFiles.has(sourcePath)) {
        return [];
    }
    loadedFiles.add(sourcePath);
    const indexesImportLines = indexesOf(sourceLines, (s) => /^# ?import "[^"]+"$/g.test(s));
    for (const index of indexesImportLines) {
        const relativeImportPath = sourceLines[index].split('"')[1];
        const importedFilePath = resolve(sourcePath, "..", relativeImportPath);
        const importedFileLines = readFileSync(importedFilePath, { encoding: "utf8" }).split("\n");
        sourceLines[index] = doImports(importedFileLines, importedFilePath, loadedFiles);
    }
    return sourceLines.flat();
}
const graphqlTransformer = {
    process(sourceText, sourcePath) {
        const sourceLines = sourceText.split("\n");
        const linesWithImport = doImports(sourceLines, sourcePath);
        const foldedLines = linesWithImport.reduce((prev, curr) => `${prev}\n${curr}`);
        const result = loader.call({ cacheable() { } }, foldedLines);
        const majorJestVersion = parseInt(getVersion().split(".")[0]);
        if (majorJestVersion >= 28) {
            return {
                code: result,
            };
        }
        else {
            return result;
        }
    },
};
export default graphqlTransformer;
//# sourceMappingURL=index.js.map